@@ -1,10 +1,10 @@
 /* ============================================================
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- *         from digiKam project.
- * Date  : 2003-10-01
- * Description : a kipi plugin for e-mailing images
+ * Authors: Gilles Caulier <caulier dot gilles at free.fr>
+ * Date   : 2003-10-01
+ * Description : a kipi plugin to e-mailing images
  * 
  * Copyright 2003-2005 by Gilles Caulier
+ * Copyright 2006 by Tom Albers
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,26 +55,28 @@
 #include <kbuttonbox.h>
 #include <ksqueezedtextlabel.h>
 #include <kapplication.h>
-#include <kaboutdata.h>
 #include <khelpmenu.h>
 #include <kpopupmenu.h>
 #include <kurlrequester.h>
 
 // Include files for KIPI
 
-#include <libkipi/version.h>
 #include <libkipi/imagedialog.h>
 
 // Local include files
 
-#include "sendimagesdialog.h"
+#include "kpaboutdata.h"
+#include "pluginsversion.h"
 #include "listimageserrordialog.h"
+#include "sendimagesdialog.h"
+#include "sendimagesdialog.moc"
 
 namespace KIPISendimagesPlugin
 {
 
 class ImageItem : public QListBoxText
 {
+
 public:
     ImageItem(QListBox * parent, QString const & comments, KURL const & url)
             : QListBoxText(parent), _comments(comments), _url(url)
@@ -87,6 +89,7 @@ public:
     void setName(const QString &newName) { setText(newName);                         }
 
 private:
+
     QString _comments;
     KURL    _url;
 };
@@ -115,29 +118,27 @@ void ListImageItems::dropEvent(QDropEvent *e)
     char *str;
 
     while ( (str = it.current()) != 0 )
-       {
-       QString filePath = QUriDrag::uriToLocalFile(str);
-       QFileInfo fileInfo(filePath);
+    {
+        QString filePath = QUriDrag::uriToLocalFile(str);
+        QFileInfo fileInfo(filePath);
 
-       if (fileInfo.isFile() && fileInfo.exists())
-          FilesPath.append(fileInfo.filePath());
-
-       ++it;
-       }
+        if (fileInfo.isFile() && fileInfo.exists())
+            FilesPath.append(fileInfo.filePath());
+    
+        ++it;
+    }
 
     if (FilesPath.isEmpty() == false)
        emit addedDropItems(FilesPath);
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////
-
 SendImagesDialog::SendImagesDialog(QWidget *parent, KIPI::Interface* interface,
                                    const KIPI::ImageCollection& images )
                 : KDialogBase( IconList, i18n("Email Images Options"), Help|Ok|Cancel,
                   Ok, parent, "SendImagesDialog", false, true )
 {
     m_interface = interface;
-    m_thumbJob = 0L;
+    m_thumbJob  = 0;
 
     setupImagesList();
     setupEmailOptions();
@@ -151,20 +152,17 @@ SendImagesDialog::SendImagesDialog(QWidget *parent, KIPI::Interface* interface,
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("kipiplugins",
-                                       I18N_NOOP("Send Images"),
-                                       kipi_version,
-                                       I18N_NOOP("A Kipi plugin for emailing images"),
-                                       KAboutData::License_GPL,
-                                       "(c) 2003-2005, Gilles Caulier",
-                                       0,
-                                       "http://extragear.kde.org/apps/kipi");
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Send Images"),
+                                           NULL,
+                                           KAboutData::License_GPL,
+                                           I18N_NOOP("A Kipi plugin for emailing images"),
+                                           "(c) 2003-2005, Gilles Caulier");
 
-    about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+    m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
+                       "caulier dot gilles at kdemail dot net");
 
-    m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+    m_helpButton        = actionButton( Help );
+    KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
     helpMenu->menu()->insertItem(i18n("Send Image Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
@@ -174,61 +172,70 @@ SendImagesDialog::SendImagesDialog(QWidget *parent, KIPI::Interface* interface,
 
 SendImagesDialog::~SendImagesDialog()
 {
-    if ( m_thumbJob ) delete m_thumbJob;
+    if ( m_thumbJob ) 
+        delete m_thumbJob;
+
+    delete m_about;
 }
 
 void SendImagesDialog::readSettings(void)
 {
     // Read all settings from configuration file.
+    
+    KConfig config("kipirc");
+    config.setGroup("SendImages Settings");
 
-    m_config = new KConfig("kipirc");
-    m_config->setGroup("SendImages Settings");
+    QString t = config.readPathEntry("MailAgentName", "Default");
 
-    m_mailAgentName->setCurrentText(m_config->readPathEntry("MailAgentName", "Kmail"));
+    // The _old_ Kmail (mind the lowercase 'm') called the default mailer.
+    // this is now renamed to 'Default'. It should not interfere with KMail, which
+    // is now doing what you expect.
+    
+    if (t == "Kmail") t = "Default";
+    m_mailAgentName->setCurrentText(t);
 
-    m_ThunderbirdBinPath->setURL( m_config->readEntry("ThunderbirdBinPath", "/usr/bin/thunderbird"));
+    m_ThunderbirdBinPath->setURL( config.readEntry("ThunderbirdBinPath", "/usr/bin/mozilla-thunderbird"));
 
-    if (m_config->readEntry("ImagesChangeProp", "true") == "true")
+    if (config.readEntry("ImagesChangeProp", "true") == "true")
         m_changeImagesProp->setChecked( true );
     else
         m_changeImagesProp->setChecked( false );
 
-    m_imagesResize->setCurrentItem(m_config->readNumEntry("ImageResize", 2));    // Medium size used by default...
-    m_imageCompression->setValue(m_config->readNumEntry("ImageCompression", 75));
-    m_imagesFormat->setCurrentText(m_config->readEntry("ImageFormat", "JPEG"));
-
-    if (m_config->readEntry("AddComments", "true") == "true")
+    m_imagesResize->setCurrentItem(config.readNumEntry("ImageResize", 2));  // Medium size used by default.
+    m_imageCompression->setValue(config.readNumEntry("ImageCompression", 75));
+    m_imagesFormat->setCurrentText(config.readEntry("ImageFormat", "JPEG"));
+    m_attachmentlimit->setValue(config.readNumEntry("AttachmentLimit", 10));
+        
+    if (config.readEntry("AddComments", "true") == "true")
         m_addComments->setChecked( true );
     else
         m_addComments->setChecked( false );
-
-    delete m_config;
 }
 
 void SendImagesDialog::writeSettings(void)
 {
     // Write all settings in configuration file.
 
-    m_config = new KConfig("kipirc");
-    m_config->setGroup("SendImages Settings");
-    m_config->writePathEntry("MailAgentName", m_mailAgentName->currentText());
-    m_config->writeEntry("ThunderbirdBinPath", m_ThunderbirdBinPath->url());
-    m_config->writeEntry("AddComments", m_addComments->isChecked());
-    m_config->writeEntry("ImagesChangeProp", m_changeImagesProp->isChecked());
-    m_config->writeEntry("ImageResize", m_imagesResize->currentItem());
-    m_config->writeEntry("ImageCompression", m_imageCompression->value());
-    m_config->writeEntry("ImageFormat", m_imagesFormat->currentText());
-    m_config->sync();
-    delete m_config;
+    KConfig config("kipirc");
+    config.setGroup("SendImages Settings");
+    config.writePathEntry("MailAgentName", m_mailAgentName->currentText());
+    config.writeEntry("ThunderbirdBinPath", m_ThunderbirdBinPath->url());
+    config.writeEntry("AddComments", m_addComments->isChecked());
+    config.writeEntry("ImagesChangeProp", m_changeImagesProp->isChecked());
+    config.writeEntry("ImageResize", m_imagesResize->currentItem());
+    config.writeEntry("ImageCompression", m_imageCompression->value());
+    config.writeEntry("ImageFormat", m_imagesFormat->currentText());
+    config.writeEntry("AttachmentLimit", m_attachmentlimit->value());	
+    config.sync();
 }
 
 void SendImagesDialog::setupImagesList(void)
 {
     QString whatsThis;
 
-    page_setupImagesList = addPage( i18n("Images"),
-                                    i18n("Image List to Email"),
-                                    BarIcon("image", KIcon::SizeMedium ) );
+    page_setupImagesList = addPage(i18n("Images"),
+                                   i18n("Image List to Email"),
+                                   BarIcon("image", KIcon::SizeMedium));
 
     QVBoxLayout *vlay = new QVBoxLayout( page_setupImagesList, 0, spacingHint() );
 
@@ -303,32 +310,32 @@ void SendImagesDialog::setImagesList( const KURL::List& Files )
     if ( Files.count() == 0 ) return;
 
     for( KURL::List::ConstIterator it = Files.begin(); it != Files.end(); ++it )
-      {
-      KIPI::ImageInfo imageInfo = m_interface->info( *it );
-      QString comments = imageInfo.description();
-
-      // Check if the new item already exist in the list.
-
-      bool findItem = false;
-
-      for (uint i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
-          {
-          ImageItem *pitem = static_cast<ImageItem*>( m_ImagesFilesListBox->item(i) );
-
-          if (pitem->url() == (*it))
-             findItem = true;
-          }
-
-      if (findItem == false)
-         {
-         ImageItem *item = new ImageItem( m_ImagesFilesListBox,
-                                          comments,                   // Image comments.
-                                          *it                         // Complete url (path & file name).
-                                        );
-
-         item->setName( (*it).fileName() );
-         }
-      }
+    {
+        KIPI::ImageInfo imageInfo = m_interface->info( *it );
+        QString comments = imageInfo.description();
+    
+        // Check if the new item already exist in the list.
+    
+        bool findItem = false;
+    
+        for (uint i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
+        {
+            ImageItem *pitem = static_cast<ImageItem*>( m_ImagesFilesListBox->item(i) );
+    
+            if (pitem->url() == (*it))
+                findItem = true;
+        }
+    
+        if (findItem == false)
+        {
+            ImageItem *item = new ImageItem(m_ImagesFilesListBox,
+                                            comments,               // Image comments.
+                                            *it                     // Complete url (path & file name).
+                                            );
+    
+            item->setName( (*it).fileName() );
+        }
+    }
 
     m_ImagesFilesListBox->setCurrentItem( m_ImagesFilesListBox->count()-1) ;
     slotImageSelected(m_ImagesFilesListBox->item(m_ImagesFilesListBox->currentItem()));
@@ -339,9 +346,9 @@ void SendImagesDialog::setupEmailOptions(void)
 {
     QString whatsThis;
 
-    page_setupEmailOptions = addPage( i18n("Mail"),
-                                      i18n("Mail Options"),
-                                      BarIcon("mail_generic", KIcon::SizeMedium ) );
+    page_setupEmailOptions = addPage(i18n("Mail"),
+                                     i18n("Mail Options"),
+                                     BarIcon("mail_generic", KIcon::SizeMedium));
 
     QVBoxLayout *vlay = new QVBoxLayout( page_setupEmailOptions, 0, spacingHint() );
 
@@ -353,22 +360,23 @@ void SendImagesDialog::setupEmailOptions(void)
     QLabel *m_mailAgentLabel = new QLabel( i18n("Mail agent:"), page_setupEmailOptions);
 
     m_mailAgentName = new QComboBox( false, page_setupEmailOptions );
+    m_mailAgentName->insertItem( "Default" );
     m_mailAgentName->insertItem( "Balsa" );
     m_mailAgentName->insertItem( "Evolution" );
     m_mailAgentName->insertItem( "GmailAgent" );
-    m_mailAgentName->insertItem( "Kmail" );
+    m_mailAgentName->insertItem( "KMail" );
     m_mailAgentName->insertItem( "Mozilla" );
     m_mailAgentName->insertItem( "Netscape" );
     m_mailAgentName->insertItem( "Sylpheed" );
     m_mailAgentName->insertItem( "Sylpheed-Claws" );
     m_mailAgentName->insertItem( "Thunderbird" );
-    m_mailAgentName->setCurrentText( "Kmail" );
+    m_mailAgentName->setCurrentText( "Default" );
     QWhatsThis::add( m_mailAgentName, i18n("<p>Select here your preferred external mail agent program."
                                            "These mail agent versions are supported:<p>"
                                            "<b>Balsa</b>: >= 2.x<p>"
                                            "<b>Evolution</b>: >= 1.4<p>"
                                            "<b>GmailAgent</b>: >= 0.2<p>"
-                                           "<b>Kmail</b>: >= 1.3<p>"
+                                           "<b>KMail</b>: >= 1.3<p>"
                                            "<b>Mozilla</b>: >= 1.4<p>"
                                            "<b>Netscape</b>: >= 7.x<p>"
                                            "<b>Sylpheed</b>: >= 0.9<p>"
@@ -391,15 +399,15 @@ void SendImagesDialog::setupEmailOptions(void)
     m_labelThunderbirdBinPath->setBuddy( m_ThunderbirdBinPath );
     vlay->addWidget(m_ThunderbirdBinPath);
 
-    connect( m_ThunderbirdBinPath, SIGNAL(textChanged(const QString&)),
-             this, SLOT(slotThunderbirdBinPathChanged(const QString&)));
+    connect(m_ThunderbirdBinPath, SIGNAL(textChanged(const QString&)),
+            this, SLOT(slotThunderbirdBinPathChanged(const QString&)));
 
     QWhatsThis::add( m_ThunderbirdBinPath, i18n("<p>The path name to the Thunderbird binary program.") );
 
     //---------------------------------------------
 
-    m_addComments = new QCheckBox( i18n("Add comments in attached file"), page_setupEmailOptions);
-    QWhatsThis::add( m_addComments, i18n("<p>If you enable this option, all images comments "
+    m_addComments = new QCheckBox( i18n("Attach a file with comments and tags"), page_setupEmailOptions);
+    QWhatsThis::add( m_addComments, i18n("<p>If you enable this option, all images comments and tags "
                                          "will be added as an attached file.") );
     vlay->addWidget( m_addComments );
 
@@ -429,6 +437,7 @@ void SendImagesDialog::setupEmailOptions(void)
     m_imagesResize->insertItem(i18n("Medium (800 pixels)"));
     m_imagesResize->insertItem(i18n("Big (1024 pixels)"));
     m_imagesResize->insertItem(i18n("Very Big (1280 pixels)"));
+    m_imagesResize->insertItem(i18n("Huge - for printing (1600 pixels)"));
     m_imagesResize->setCurrentText (i18n("Medium (800 pixels)"));
     whatsThis = i18n("<p>Select here the images size to send:<p>"
                      "<b>%1</b>: use this if you have a very slow internet "
@@ -439,12 +448,14 @@ void SendImagesDialog::setupEmailOptions(void)
                      "and a target mailbox size.<p>"
                      "<b>%4</b>: use this if you have a high-speed internet connection "
                      "and if the target mailbox size is not limited.<p>"
-                     "<b>%5</b>: use this if you have no size or speed restrictions.<p>")
+                     "<b>%5</b>: use this if you have no size or speed restrictions.<p>"
+                     "<b>%6</b>: use this only for printing purpose.<p>")
                      .arg(i18n("very small (320 pixels)"))
                      .arg(i18n("small (640 pixels)"))
                      .arg(i18n("medium (800 pixels)"))
                      .arg(i18n("big (1024 pixels)"))
-                     .arg(i18n("very big (1280 pixels)"));
+                     .arg(i18n("very big (1280 pixels)"))
+		     .arg(i18n("huge - for printing (1600 pixels)"));
     QWhatsThis::add( m_imagesResize, whatsThis );
 
     m_labelImageSize = new QLabel( i18n("New images size:"), groupBox2);
@@ -470,7 +481,7 @@ void SendImagesDialog::setupEmailOptions(void)
 
     //---------------------------------------------
 
-    QHBoxLayout *hlay13  = new QHBoxLayout( );
+    QHBoxLayout *hlay13  = new QHBoxLayout();
     groupBox2Layout->addLayout( hlay13 );
 
     m_imagesFormat = new QComboBox(false, groupBox2);
@@ -488,15 +499,21 @@ void SendImagesDialog::setupEmailOptions(void)
                 "and chromaticity data for improved color matching on heterogeneous platforms.");
     QWhatsThis::add( m_imagesFormat, whatsThis );
 
-    m_labelImageFormat = new QLabel( i18n("Images file format:"), groupBox2);
-    hlay13->addWidget( m_labelImageFormat );
-    m_labelImageFormat->setBuddy( m_imagesFormat );
-    hlay13->addStretch( 1 );
+    m_labelImageFormat = new QLabel(i18n("Images file format:"), groupBox2);
+    hlay13->addWidget(m_labelImageFormat);
+    m_labelImageFormat->setBuddy(m_imagesFormat);
+    hlay13->addStretch(1);
     hlay13->addWidget(m_imagesFormat);
 
-    vlay->addWidget( groupBox2 );
+    vlay->addWidget(groupBox2);
     vlay->addStretch(1);
 
+    m_attachmentlimit = new KIntNumInput(17, page_setupEmailOptions);
+    m_attachmentlimit->setRange(1, 50, 1, true );
+    m_attachmentlimit->setLabel( i18n("Maximum Email Size:"));
+    m_attachmentlimit->setSuffix(i18n("MB"));
+    vlay->addWidget( m_attachmentlimit );
+		    
     //---------------------------------------------
 
     connect(m_changeImagesProp, SIGNAL(toggled(bool)),
@@ -523,15 +540,15 @@ void SendImagesDialog::slotHelp()
 void SendImagesDialog::slotMailAgentChanged(int)
 {
     if ( m_mailAgentName->currentText() == "Thunderbird" )
-       {
-       m_labelThunderbirdBinPath->setEnabled(true);
-       m_ThunderbirdBinPath->setEnabled(true);
-       }
+    {
+        m_labelThunderbirdBinPath->setEnabled(true);
+        m_ThunderbirdBinPath->setEnabled(true);
+    }
     else
-       {
+    {
        m_labelThunderbirdBinPath->setEnabled(false);
        m_ThunderbirdBinPath->setEnabled(false);
-       }
+    }
 }
 
 void SendImagesDialog::slotThunderbirdBinPathChanged(const QString &url )
@@ -558,14 +575,14 @@ void SendImagesDialog::slotImagesFilesButtonAdd( void )
 void SendImagesDialog::slotImagesFilesButtonRem( void )
 {
     for (uint i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
-       {
-       if (m_ImagesFilesListBox->isSelected(i))
-           {
-           m_ImagesFilesListBox->removeItem(i);
-           m_ImagesFilesListBox->setCurrentItem(i);
-           --i;
-           }
-       }
+    {
+        if (m_ImagesFilesListBox->isSelected(i))
+        {
+            m_ImagesFilesListBox->removeItem(i);
+            m_ImagesFilesListBox->setCurrentItem(i);
+            --i;
+        }
+    }
 
     m_ImagesFilesListBox->setSelected(m_ImagesFilesListBox->item(m_ImagesFilesListBox->currentItem()), true);
     slotImageSelected(m_ImagesFilesListBox->item(m_ImagesFilesListBox->currentItem()));
@@ -575,10 +592,10 @@ void SendImagesDialog::slotImagesFilesButtonRem( void )
 void SendImagesDialog::slotImageSelected( QListBoxItem * item )
 {
     if ( !item || m_ImagesFilesListBox->count() == 0 )
-       {
-       m_imageLabel->clear();
-       return;
-       }
+    {
+        m_imageLabel->clear();
+        return;
+    }
 
     ImageItem *pitem = static_cast<ImageItem*>( item );
 
@@ -588,7 +605,8 @@ void SendImagesDialog::slotImageSelected( QListBoxItem * item )
     m_ImageAlbum->setText( i18n("Album: %1").arg(pitem->album()) );
     m_imageLabel->clear();
 
-    if ( m_thumbJob ) delete m_thumbJob;
+    if ( m_thumbJob ) 
+        delete m_thumbJob;
 
     m_thumbJob = KIO::filePreview( pitem->url(), m_imageLabel->height() );
 
@@ -613,29 +631,29 @@ void SendImagesDialog::slotFailedPreview(const KFileItem*)
 void SendImagesDialog::slotOk()
 {
     if ( m_ImagesFilesListBox->count() == 0 )
-       {
-       KMessageBox::error(this, i18n("You must add some images to send."));
-       return;
-       }
+    {
+        KMessageBox::error(this, i18n("You must add some images to send."));
+        return;
+    }
 
     if ( m_mailAgentName->currentText() == "Thunderbird" )
-       {
-       QFile fileThunderbird(m_ThunderbirdBinPath->url());
-
-       if (fileThunderbird.exists() == false)
-          {
-          KMessageBox::sorry(this, i18n("Thunderbird binary path is not valid. Please check it."));
-          return;
-          }
-       }
+    {
+        QFile fileThunderbird(m_ThunderbirdBinPath->url());
+    
+        if (fileThunderbird.exists() == false)
+        {
+            KMessageBox::sorry(this, i18n("Thunderbird binary path is not valid. Please check it."));
+            return;
+        }
+    }
 
     writeSettings();
 
     for (uint i = 0 ; i < m_ImagesFilesListBox->count() ; i++)
-        {
+    {
         ImageItem *pitem = static_cast<ImageItem*>( m_ImagesFilesListBox->item(i) );
         m_images2send << pitem->url();
-        }
+    }
 
     emit signalAccepted();
     accept();
@@ -651,4 +669,3 @@ void SendImagesDialog::setNbItems(void)
 
 }  // NameSpace KIPISendimagesPlugin
 
-#include "sendimagesdialog.moc"
