@@ -38,7 +38,6 @@
 // KDE include files
 
 #include <klocale.h>
-#include <kaboutdata.h>
 #include <khelpmenu.h>
 #include <kpopupmenu.h>
 #include <kiconloader.h>
@@ -47,15 +46,18 @@
 #include <kcolorbutton.h>
 #include <kurlrequester.h>
 #include <kglobalsettings.h>
+#include <kconfig.h>
 
 // KIPI include files
 
-#include <libkipi/version.h>
 #include <libkipi/imagecollectionselector.h>
 
 // Local include files
 
+#include "kpaboutdata.h"
+#include "pluginsversion.h"
 #include "svedialog.h"
+#include "svedialog.moc"
 
 namespace KIPISimpleViewerExportPlugin
 {
@@ -71,35 +73,34 @@ SVEDialog::SVEDialog(KIPI::Interface* interface, QWidget *parent)
     generalPage();
     lookPage();
 
+    readConfig();
+
     resize( 650, 450 );
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("kipiplugins",
-                                       I18N_NOOP("Simple Viewer"),
-                                       kipi_version,
-                                       I18N_NOOP("A Kipi plugin for Simple Viewer export."),
-                                       KAboutData::License_GPL,
-                                       "(c) 2005-2006, Joern Ahrens",
-                                       0,
-                                       "http://www.jokele.de/simpleviewerexport/");
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Simple Viewer"),
+                                           NULL,
+                                           KAboutData::License_GPL,
+                                           I18N_NOOP("A Kipi plugin for Simple Viewer export."),
+                                           "(c) 2005-2006, Joern Ahrens");
 
-    about->addAuthor("Joern Ahrens", 
-                     I18N_NOOP("Author and maintainer"),
-                     "joern dot ahrens at kdemail dot net");
+    m_about->addAuthor("Joern Ahrens", 
+                       I18N_NOOP("Author and maintainer"),
+                       "joern dot ahrens at kdemail dot net");
     
-    about->addCredit("Felix Turner",
-                     "Author of the SimpleViewer flash application",
-                     0,
-                     "http://www.airtightinteractive.com/simpleviewer/");
+    m_about->addCredit("Felix Turner",
+                       "Author of the SimpleViewer flash application",
+                       0,
+                       "http://www.airtightinteractive.com/simpleviewer/");
     
-    about->addCredit("Mikkel B. Stegmann",
-                     "Basis for the index.html template",
-                     0,
-                     "http://www.stegmann.dk/mikkel/porta/");
+    m_about->addCredit("Mikkel B. Stegmann",
+                       "Basis for the index.html template",
+                       0,
+                       "http://www.stegmann.dk/mikkel/porta/");
 
     QPushButton *helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+    KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
 //    helpMenu->menu()->insertItem(i18n("Image Gallery Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     helpButton->setPopup( helpMenu->menu() );
@@ -107,6 +108,55 @@ SVEDialog::SVEDialog(KIPI::Interface* interface, QWidget *parent)
 
 SVEDialog::~SVEDialog()
 {
+    delete m_about;
+}
+
+void SVEDialog::readConfig()
+{
+    KConfig *config = new KConfig("kipisimpleviewerexportrc");
+    
+    setThumbnailRows(config->readNumEntry("thumbnailRows", 1));
+    setThumbnailColumns(config->readNumEntry("thumbnailColumns", 1));
+    m_navPosition->setCurrentItem(config->readNumEntry("navPosition", 1));
+    m_navDirection->setCurrentItem(config->readNumEntry("navDirection", 1));
+    setTextColor(QColor(config->readEntry("textColor", "#ffffff")));
+    setBackgroundColor(QColor(config->readEntry("backgroundColor", "#181818")));    
+    setFrameColor(QColor(config->readEntry("frameColor", "#ffffff")));    
+    setFrameWidth(config->readNumEntry("frameWidth", 1));
+    setStagePadding(config->readNumEntry("stagePadding", 1));
+    setTitle(config->readEntry("title", ""));
+    m_exportURL->setURL(config->readPathEntry("exporturl",  KGlobalSettings::documentPath() + "simpleviewer"));
+    setResizeExportImages(config->readBoolEntry("resizeExportImages", true));
+    setImagesExportSize(config->readNumEntry("imagesExportSize", 640));
+    setMaxImagesDimension(config->readNumEntry("maxImageDimension", 640));
+    setShowExifComments(config->readBoolEntry("showExifComments", true));    
+        
+    delete config;
+}
+
+void SVEDialog::writeConfig()
+{
+    KConfig *config = new KConfig("kipisimpleviewerexportrc");
+    
+    config->writeEntry("thumbnailRows", thumbnailRows());
+    config->writeEntry("thumbnailColumns", thumbnailColumns());
+    config->writeEntry("navPosition", m_navPosition->currentItem());
+    config->writeEntry("navDirection", m_navDirection->currentItem());
+    config->writeEntry("textColor", textColor().name());
+    config->writeEntry("backgroundColor", backgroundColor().name());    
+    config->writeEntry("frameColor", frameColor().name());
+    config->writeEntry("frameWidth", frameWidth());
+    config->writeEntry("stagePadding", stagePadding());            
+    config->writePathEntry("exporturl", exportURL());
+    config->writeEntry("title", title());
+    config->writeEntry("resizeExportImages", resizeExportImages());
+    config->writeEntry("imagesExportSize", imagesExportSize());
+    config->writeEntry("maxImageDimension", maxImageDimension());
+    config->writeEntry("showExifComments", showExifComments());
+    
+    config->sync(); 
+    
+    delete config;
 }
 
 void SVEDialog::selectionPage()
@@ -319,7 +369,7 @@ void SVEDialog::slotOk()
         KMessageBox::sorry(this, i18n("You must select at least one album."));
         return;
     }
-
+    writeConfig();
     accept();
 }
 
@@ -464,9 +514,9 @@ QString SVEDialog::navDirection() const
 void SVEDialog::setNavDirection(const QString &direction)
 {
     if(direction == "LTR")
-        m_navPosition->setCurrentText(i18n("Left to Right"));
+        m_navDirection->setCurrentText(i18n("Left to Right"));
     else
-        m_navPosition->setCurrentText(i18n("Right Left"));
+        m_navDirection->setCurrentText(i18n("Right to Left"));
 }
 
 QString SVEDialog::navPosition() const
@@ -490,4 +540,3 @@ void SVEDialog::setNavPosition(const QString &pos)
 
 } //  namespace KIPISimpleViewerExportPlugin
 
-#include "svedialog.moc"
