@@ -1,10 +1,11 @@
 /* ============================================================
- * File  : plugin_timeadjust.h
- * Author: Jesper K. Pedersen <blackie@kde.org>
- * Date  : 2004-05-16
- * Description :
+ * Authors: Jesper K. Pedersen <blackie@kde.org>
+ *          Gilles Caulier <caulier dot gilles at kdemail dot net>
+ * Date   : 2004-05-16
+ * Description : a plugin to set time stamp of picture files.
  *
- * Copyright 2003 by Jesper Pedersen
+ * Copyright 2003-2005 by Jesper Pedersen
+ * Copyright 2006 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -28,27 +29,26 @@
 
 class KAction;
 
-class KIPITimeAdjustPlugin::TimeAdjustDialog;
-
 class Plugin_TimeAdjust : public KIPI::Plugin
 {
     Q_OBJECT
 
 public:
-    Plugin_TimeAdjust(QObject *parent,
-                      const char* name,
-                      const QStringList &args);
+
+    Plugin_TimeAdjust(QObject *parent, const char* name, const QStringList &args);
 
     virtual KIPI::Category category( KAction* action ) const;
     virtual void setup( QWidget* );
 
 protected slots:
+
     void slotActivate();
 
 private:
-    KIPI::Interface                        *m_interface;
-    KIPITimeAdjustPlugin::TimeAdjustDialog *m_dialog;
-    KAction                                *m_actionTimeAjust;
+
+    KAction         *m_actionTimeAjust;
+
+    KIPI::Interface *m_interface;
 };
 
-#endif
+#endif // PLUGIN_TIMEADJUST_H
